@@ -475,6 +475,17 @@ class TestXUpdateProcessor(unittest.TestCase):
       <error_message type="string"/>
       <state type="string">current</state>
     </xupdate:element>
+    <a>
+      <a>
+        <a/>
+        <b/>
+        <c/>
+      </a>
+      <b/>
+      <c/>
+    </a>
+    <b/>
+    <c/>
   </xupdate:insert-after>
   <xupdate:insert-after select="/erp5/object1">
     <action type="string">edit</action>
@@ -498,6 +509,17 @@ class TestXUpdateProcessor(unittest.TestCase):
     <error_message type="string"/>
     <state type="string">current</state>
   </workflow_action>
+  <a>
+    <a>
+      <a/>
+      <b/>
+      <c/>
+    </a>
+    <b/>
+    <c/>
+  </a>
+  <b/>
+  <c/>
   <object1/>
   <action type="string">edit</action>
   <comment type="None"/>
